ChargeObject class

A simple ChargeObject Entity Charge Objects are a model for the responses gotten from Coinbase when charge requests are made. It contains all the accompanying data from such request resulting information from Charge Objects can be further utilized to determine the status of a given charge.

Inheritance

Constructors

ChargeObject({DateTime? confirmedAt, Map? pricing, bool? isSuccessful, ErrorObject? error, String? cancelUrl, String? redirectUrl, Map? metaData, String? name, List? payments, String? pricingType, List? timeline, String? supportEmail, String? id, String? url, Map? addresses, String? code, DateTime? createdAt, String? description, Map? exchangeRate, DateTime? expiresAt})
ChargeObject.fromJson(Map data)
factory

Properties

addresses → Map?
final
cancelUrl → String?
final
code → String?
final
confirmedAt → DateTime?
final
createdAt → DateTime?
final
description → String?
final
error → ErrorObject?
final
exchangeRate → Map?
final
expiresAt → DateTime?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
isSuccessful → bool?
final
metaData → Map?
final
name → String?
final
payments → List?
final
pricing → Map?
final
pricingType → String?
final
redirectUrl → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportEmail → String?
final
timeline → List?
final
url → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Returns the ChargeObject fields as a String object
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited