CheckoutObject class

A simple CheckoutObject entity CheckoutObject is a model for the responses gotten from Coinbase when checkout requests are made. It contains all the accompanying data from such request resulting information from Checkout Objects can be further utilized to determine the status of a given Checkout.

Inheritance

Constructors

CheckoutObject({String? url, String? description, String? id, String? name, String? pricingType, bool? isSuccessful, ErrorObject? error, List? requestedInfo})
CheckoutObject.fromJson(Map data)
factory

Properties

description → String?
final
error → ErrorObject?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
isSuccessful → bool?
final
name → String?
final
pricingType → String?
final
requestedInfo → List?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Returns the CheckoutObject fields as a String object
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited