ErrorObject class

A simple ErrorObject entity.

Inheritance

Constructors

ErrorObject({String? type, String? message})
Returns an entity containing the type of error and the accompanying message for
ErrorObject.fromJson(Map data)
Creates an ErrorObject using the fields of the response from Coinbase
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String?
The body of the error response
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String?
The type of Error message that resulted from the request made
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Returns the ErrorObject fields as a String object
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited