InvoiceObject class

A check to confirm whether the response completed successfully An isSuccessful value is contained in each of the CoinbaseChargeObjects this value shows returns true when there is a successful request

Inheritance

Constructors

InvoiceObject({bool? isSuccessful, ErrorObject? error, String? businessName, String? code, String? status, String? customerName, String? customerEmail, String? url, ChargeObject? charge, String? memo, DateTime? createdAt, DateTime? updatedAt, Map? localPrice})
InvoiceObject.fromJson(Map data)
factory

Properties

businessName → String?
final
charge → ChargeObject?
final
code → String?
final
createdAt → DateTime?
final
customerEmail → String?
final
customerName → String?
final
error → ErrorObject?
final
hashCode → int
The hash code for this object.
no setterinherited
isSuccessful → bool?
final
localPrice → Map?
final
memo → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String?
final
updatedAt → DateTime?
final
url → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Returns the InvoiceObject as a String object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited