StatusObject class

the StatusObject shows the current Status of the of any request that has been made

Constructors

StatusObject({TransactionStatus? status, String? context, DateTime? time})

Properties

context → String?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → TransactionStatus?
final
time → DateTime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited